From f1d58b9fb39bb9b029147688c422d2d7c9a633b0 Mon Sep 17 00:00:00 2001
From: Fujii Masao <fujii@postgresql.org>
Date: Tue, 22 Jul 2025 21:01:57 +0900
Subject: [PATCH v1] Remove translation marker from libpq-be-fe-helpers.h.
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Commit 112faf1378e introduced a translation marker in libpq-be-fe-helpers.h,
but this caused build failures on some platforms—such as the one reported
by buildfarm member indri—due to linker issues with dblink. This is the same
problem previously addressed in commit 213c959a294.

To fix the issue, this commit removes the translation marker from
libpq-be-fe-helpers.h, following the approach used in 213c959a294.
It also removes the associated gettext_noop() calls added in 112faf1378e,
as they are no longer needed.

Per buildfarm member indri.

Discussion: https://postgr.es/m/0e6299d9-608a-4ffa-aeb1-40cb8a99000b@oss.nttdata.com
---
 contrib/dblink/dblink.c                                     | 4 ++--
 contrib/postgres_fdw/connection.c                           | 2 +-
 src/backend/replication/libpqwalreceiver/libpqwalreceiver.c | 2 +-
 src/include/libpq/libpq-be-fe-helpers.h                     | 2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/contrib/dblink/dblink.c b/contrib/dblink/dblink.c
index c459a842fa9..de5bed282f3 100644
--- a/contrib/dblink/dblink.c
+++ b/contrib/dblink/dblink.c
@@ -242,7 +242,7 @@ dblink_get_conn(char *conname_or_str,
 		}
 
 		PQsetNoticeReceiver(conn, libpqsrv_notice_receiver,
-							gettext_noop("received message via remote connection"));
+							"received message via remote connection");
 
 		dblink_security_check(conn, NULL, connstr);
 		if (PQclientEncoding(conn) != GetDatabaseEncoding())
@@ -343,7 +343,7 @@ dblink_connect(PG_FUNCTION_ARGS)
 	}
 
 	PQsetNoticeReceiver(conn, libpqsrv_notice_receiver,
-						gettext_noop("received message via remote connection"));
+						"received message via remote connection");
 
 	/* check password actually used if not superuser */
 	dblink_security_check(conn, connname, connstr);
diff --git a/contrib/postgres_fdw/connection.c b/contrib/postgres_fdw/connection.c
index e41d47c3bbd..c1ce6f33436 100644
--- a/contrib/postgres_fdw/connection.c
+++ b/contrib/postgres_fdw/connection.c
@@ -626,7 +626,7 @@ connect_pg_server(ForeignServer *server, UserMapping *user)
 					 errdetail_internal("%s", pchomp(PQerrorMessage(conn)))));
 
 		PQsetNoticeReceiver(conn, libpqsrv_notice_receiver,
-							gettext_noop("received message via remote connection"));
+							"received message via remote connection");
 
 		/* Perform post-connection security checks. */
 		pgfdw_security_check(keywords, values, user, conn);
diff --git a/src/backend/replication/libpqwalreceiver/libpqwalreceiver.c b/src/backend/replication/libpqwalreceiver/libpqwalreceiver.c
index 0c75fe064d5..886d99951dd 100644
--- a/src/backend/replication/libpqwalreceiver/libpqwalreceiver.c
+++ b/src/backend/replication/libpqwalreceiver/libpqwalreceiver.c
@@ -233,7 +233,7 @@ libpqrcv_connect(const char *conninfo, bool replication, bool logical,
 	}
 
 	PQsetNoticeReceiver(conn->streamConn, libpqsrv_notice_receiver,
-						gettext_noop("received message via replication"));
+						"received message via replication");
 
 	/*
 	 * Set always-secure search path for the cases where the connection is
diff --git a/src/include/libpq/libpq-be-fe-helpers.h b/src/include/libpq/libpq-be-fe-helpers.h
index 49137a0a570..af13bd6bf3d 100644
--- a/src/include/libpq/libpq-be-fe-helpers.h
+++ b/src/include/libpq/libpq-be-fe-helpers.h
@@ -481,7 +481,7 @@ libpqsrv_notice_receiver(void *arg, const PGresult *res)
 		len--;
 
 	ereport(LOG,
-			errmsg_internal("%s: %.*s", _(prefix), len, message));
+			errmsg_internal("%s: %.*s", prefix, len, message));
 }
 
 #endif							/* LIBPQ_BE_FE_HELPERS_H */
-- 
2.50.1

